#
# spec file for package singularity
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define libsingularity libsingularity1

%define git_version 2.3.2
#%%define not_yet 0

# slurm build broken
%define have_slurm 0

%define allow_suid 1

# for the perl git file parser to run, none of the 
# macros used in the variables must contain shell code.
%define github_ref %{?git_sha}%{!?git_sha:%git_version}

Name:           singularity
Version:        %git_version
Release:        lp150.1.19
Summary:        Application and environment virtualization
License:        BSD-3-Clause
Group:          Productivity/Clustering/Computing
Url:            http://singularity.lbl.gov/
#Source:		https://github.com/singularityware/%%{name}/tarball/%%{github_ref}#/%%{name}-%%{version}.tar.gz
Source:         https://github.com/singularityware/%{name}/archive/%{github_ref}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        README.SUSE
Source5:        singularity-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%if 0%{?have_slurm}
BuildRequires:  slurm-devel
%endif
BuildRequires:  fdupes
BuildRequires:  python
%{?allow_suid:Requires(pre):  shadow}
PreReq:         permissions >= 20170922
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Singularity provides functionality to build the smallest most minimal
possible containers, and running those containers as single application
environments.

%package devel
Summary:        Development package for Singularity
Group:          Development/Libraries/C and C++
Requires:       %{libsingularity} = %{version}
Requires:       %{name} = %{version}

%description devel
Development package for singularity. This package includes the header files
and libraries for the Singularity API.

%package -n %{libsingularity}
Summary:        Libraries for Singularity
Group:          System/Libraries

%description -n %{libsingularity}
This package contains the library needed to run programs dynamically linked
with Singularity.

%prep
%setup -q -n %{name}-%{github_ref}
cp %{S:1} .

%build
./autogen.sh
%configure \
    %{!?allow_suid:--disable-suid} \
    --with-userns \
    --with-gnu-ld \
%if 0%{?have_slurm}
    --with-slurm
%endif

make %{?_smp_mflags} CFLAGS+=-fPIE LDFLAGS+=-pie

%install
%makeinstall
# remove static library stuff
rm -f %{buildroot}/%{_libdir}/%{name}/lib%{name}-*.a
rm -f %{buildroot}/%{_libdir}/%{name}/lib%{name}-*.la
# fix broken permissions
chmod a-x %{buildroot}/%{_libexecdir}/%{name}/python/docker/__init__.py
chmod a-x %{buildroot}/%{_libexecdir}/%{name}/python/__init__.py
%fdupes  %{buildroot}

%post -n %{libsingularity} -p /sbin/ldconfig

%postun -n %{libsingularity} -p /sbin/ldconfig

%if 0%{allow_suid:1}
%pre 
getent group %{name} >/dev/null || groupadd -r %{name}
exit 0

%post
%set_permissions %{_libexecdir}/%{name}/bin/expand-suid
%set_permissions %{_libexecdir}/%{name}/bin/mount-suid
%set_permissions %{_libexecdir}/%{name}/bin/create-suid
%set_permissions %{_libexecdir}/%{name}/bin/action-suid
%set_permissions %{_libexecdir}/%{name}/bin/export-suid
%set_permissions %{_libexecdir}/%{name}/bin/import-suid
%if 0%{?not_yet:1}
%set_permissions %{_libexecdir}/%{name}/bin/start-suid
%endif

%verifyscript
%verify_permissions %{_libexecdir}/%{name}/bin/expand-suid
%verify_permissions %{_libexecdir}/%{name}/bin/mount-suid
%verify_permissions %{_libexecdir}/%{name}/bin/create-suid
%verify_permissions %{_libexecdir}/%{name}/bin/action-suid
%verify_permissions %{_libexecdir}/%{name}/bin/export-suid
%verify_permissions %{_libexecdir}/%{name}/bin/import-suid
%if 0%{?not_yet:1}
%set_permissions %{_libexecdir}/%{name}/bin/start-suid
%endif
%endif

%files
%defattr(-,root,root)
%doc examples CONTRIBUTING.md LICENSE-LBNL.md README.md %{basename:%{S:1}}
%if 0%{?not_yet:1}
%doc COPYRIGHT.md CONTRIBUTORS.md LICENSE.md
%else
%doc AUTHORS.md
%endif
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/default-nsswitch.conf
%config(noreplace) %{_sysconfdir}/%{name}/init
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%if 0%{?not_yet:1}
%config(noreplace) %{_sysconfdir}/%{name}/nvliblist.conf
%endif
%{_sysconfdir}/bash_completion.d/%{name}
%{_bindir}/%{name}
%{_bindir}/run-%{name}
%{_libexecdir}/%{name}
%exclude %{_libdir}/%{name}/lib%{name}-*.so*
%{?allow_suid:%verify(not mode) %attr(4750,root,%{name}) %{_libexecdir}/%{name}/bin/*-suid}
%{_mandir}/man1/%{name}.1.gz

%files -n %{libsingularity}
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}-*.so.*

%files devel
%defattr(-,root,root)
%dir /usr/include/%{name}
/usr/include/%{name}/*.h
%{_libdir}/%{name}/lib%{name}-*.so

%changelog
* Mon Nov  6 2017 eich@suse.com
- Restrict permissions file version to a version which has
  the required singularity entries.
* Thu Nov  2 2017 eich@suse.com
- Update to 2.3.2:
  * Fix for a change that Docker implemented to their registry
    RESTful API which broke compatibility with Singularity.
  * Several other low minor fixes.
* Thu Oct  5 2017 eich@suse.com
- Removed:
  Do-chdir-before-duing-chroot.patch:
  After checking with the security team that there are no concerns
  about doing the chdir() after the chroot(), remove this patch and
  add a filter to keep rpmlint from complaining (bsc#1028304).
* Mon Oct  2 2017 eich@suse.com
- set permissions for SUID binaries to 4750.
- fix library packaging for i586.
- add a README.SUSE
- temporarily filter filter for non-standard-gid from rpmlint
  until group 'singularity' is available as known group.
* Thu Sep 14 2017 eich@suse.com
- Update to version 2.3.1:
  This release includes a fix for a High Severity security issue on older
  hosts, and other improvements and fixes to previous versions of Singularity.
  Version 2.3:
  There are a massive number of fixes, updates, optimizations and awesomeness
  contained within this release, but here is a brief overview of the major
  changes you can expect to find in this release:
    Lots of backend library changes to accommodate a more flexible API
    Restructured Python backend
    Updated bootstrap backend to make it much more reliable
    Direct support for the awesome, the fantastic, Singularity-Hub!
    Ability to run additional commands without root privileges (e.g. create,
    import, copy, export, etc..).
    Added ability to pull images from Singularity Hub and Docker
    Containers now have labels, and are inspect'able
- Do-chdir-before-duing-chroot.patch:
  Add a chdir() before chroot() just to keep rpmlint from complaining
  even more. There is a chdir("/") right after the chroot() call.
- Created group 'singularity' and make suid-root binaries only executable
  by this group.
* Sat Feb 18 2017 eich@suse.com
- Initial import of singuarity 2.2.1.
